Function to validate if a created boundary satisfies a given instance row
Source:R/mab_utils.R
validate_bound.RdFunction to validate if a created boundary satisfies a given instance row

R/mab_utils.R
validate_bound.RdFunction to validate if a created boundary satisfies a given instance row