Function to validate whether every edge case of the environment can contain the row
Source:R/mab_utils.R
validate_environment.RdFunction to validate whether every edge case of the environment can contain the row

R/mab_utils.R
validate_environment.RdFunction to validate whether every edge case of the environment can contain the row